#[derive(SubslicesMut)]
{
// Attributes available to this derive:
#[value_traits_subslices_mut]
}
A derive macro fully implementing mutable subslices on top of a
SliceByValueMut for which the derive macro Subslices has been
already applied.
The macro defines a structure <YOUR TYPE>SubsliceImplMut that keeps track
of a mutable reference to a slice, and of the start and end of the subslice.
<YOUR TYPE>SubsliceImplMut then implements SliceByValueMut,
SliceByValueSubslice, and SliceByValueSubsliceMut.
The generated structure has the same visibility as the type the macro is applied to.
Note that SliceByValueSubslice methods will return the
<YOUR TYPE>SubsliceImpl structure generated by the Subslices macro.
Chunks
Presently, try_chunks_mut is not supported.
Additional Bounds
Since this macro has no knowledge of the bounds of the generic parameters in
the implementations of SliceByValue and SliceByValueMut,
additional bounds with respect to the type declaration must be specified
using the #[value_traits_subslices_mut(bound = "<BOUND>")] attribute.
Multiple bounds can be specified with multiple attributes.